require "markit/version"
require 'HTTParty'

module MarkIt
	
#List of methods available for calling.
	METHODS = {
		:name => "Name", #name of the company
		:last_price => "LastPrice", #last traded price
		:change => "Change", #dollar amount change in the price from open to last price today
		:change_percent => "ChangePercent", #percent amount change in the price from open to last price today
		:market_cap => "MarketCap", #market capitalization of the company
		:volume => "Volume", #number of shares traded today
		:change_percent_ytd => "ChangePercentYTD", #percent amount change in the price in the year to date
		:high => "High", #highest price in the current trading session
		:low => "Low", #lowest price in the current trading session
		:open => "Open" #price the stock started at in the current trading session
	}

#To use, initialize with MarkIt::Quote.new(ticker) where ticker is a string of the company's trading symbol
#e.g. aapl = MarkIt::Quote.new("AAPL")
	class Quote
		include HTTParty


		attr_accessor :ticker, :info

		base_uri "http://dev.markitondemand.com/Api/Quote?"

		def initialize(ticker) #ticker is a string of the company's trading symbol
			self.ticker = ticker
			self.info = self.class.get("symbol=#{ticker}") #GET method
			if self.info["Error"]
				self.info = "Error. Please enter a new ticker."
			end
		end

		METHODS.each do |k,v|
			self.class_eval do
				define_method "#{k.to_s}" do
					info["QuoteApiModel"]["Data"]["#{v}"]
				end
			end
		end

		def change_ytd
			(last_price.to_f - info["QuoteApiModel"]["Data"]["ChangeYTD"].to_f).to_s
		end
	end

end